//
//  MCLShareConfig.h
//  Megacool
//
//  Created by Tarjei Husøy on 12/27/17.
//  Copyright © 2017 Nicolaj Broby Petersen. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>

#import "MCLShare.h"

/*!
 @brief Configure how a share is performed.
 @discussion This class does not have atomic properties for efficiency, thus it's not thread safe.
 */
@interface MCLShareConfig : NSObject
NS_ASSUME_NONNULL_BEGIN

/*!
 @brief Which recording to share
 */
@property(nonatomic, nullable) NSString *recordingId;

/*!
 @brief A fallback to share if there are no frames in the given recording
 or something fails. Mutually exclusive with @c fallbackImage.
 */
@property(nonatomic, nullable) NSURL *fallbackImageUrl;

/*!
 @brief A fallback to to share if there are no frames in the given recording
 or something fails. Mutually exclusive with @c fallbackImageUrl.
 */
@property(nonatomic, nullable) UIImage *fallbackImage;

/*!
 @brief Customize the url included in the share to navigate to a specific section
 of your app.
 @discussion The link given here can be extracted from the link-clicked event on the receiving side. Note that only the path and query parameters will be respected. If set to f. ex [NSURL URLWithString:@"/level2?difficulty=ludicruous", the final url will end up as <tt>https://mgcl.co/<your-app-identifier>/level2?difficulty=ludicruous&_m=<referral-code></tt>.
 */
@property(nonatomic, nullable) NSURL *url;

/*!
 @brief Additional data to include with the share. This will be available to the receiver in the receivedShareOpened event.
 */
@property(nonatomic, nullable) NSDictionary<NSString *, NSString *> *data;

/*!
 @brief On iPads, which view should present the popover.
 */
@property(nonatomic, nullable) UIView *sourceView;

/*!
 @brief When using @c shareToMessenger, you can force to show the composer view instead of replying directly to a friend.
 More on Messenger's reply flow here: https://developers.facebook.com/docs/messenger/ios#handling_calls_messenger
 */
@property(nonatomic) BOOL messengerForceCompose;

/*!
 @brief Deprecated, was used to configure the url and data, but you should now
 set those directly on the MCLShareConfig.
 */
@property(nonatomic, nullable) MCLShare *share __deprecated_msg("Set the url and data directly on the config");

NS_ASSUME_NONNULL_END
@end
